// Demo for controlling RemoteServo, moves all servos through 45-135 and back
// Need to change the serial port index in setupSerial to match the index of the Arduino serial port
// and change SERVO_COUNT to match the number of servos you have on the Arduino RemoteServo program

import processing.serial.*;      

Serial port;

static final int SERVO_COUNT = 10;
static final int START_POSITION = 45;
static final int END_POSITION = 135;

class RemoteServo {
  int servoIndex;
  int position = 0;
  Serial port;
  
  public RemoteServo(int servoIndex) {
    this.servoIndex  = servoIndex;
  }
  
  public int getPosition() {
    return position;
  }
  
  public void move(int position) {
    int newPosition = max(position, min(position,180),0);
    if (newPosition != this.position) {
      // build RemoteServo command
      String command = "p" + servoIndex + "m" + position + "g";
      // println(command);
      port.write(command);
      this.position = newPosition;
    }
  }
  
  public void setPort(Serial port) {
    this.port = port;
  }
  
}



void setupSerial() {
   println("Getting serial list, may take a while if there are Bluetooth ports...");
   String[] serialPorts = Serial.list();
   println(serialPorts);

   // warning hardcoded port number in list
  String   myPortName = serialPorts[1];
   
   port = new Serial(this, myPortName, 115200); 
   println("Opened serial port " + myPortName);
}

RemoteServo[] servos = new RemoteServo[SERVO_COUNT];

void setupServos() {
  for (int i=0; i<SERVO_COUNT; i++) {
    servos[i] = new RemoteServo(i);
    servos[i].setPort(port);
  }
}

void setup(){
  size(600,600);

  setupSerial();
  
  setupServos();
}

int currentPosition=45;

void draw(){
  // move servos one tick
  println(currentPosition);
  for (int i=0; i<SERVO_COUNT; i++) {
    servos[i].move(currentPosition);
  }
  currentPosition++;
  
  if (currentPosition > END_POSITION) {
    currentPosition = START_POSITION;
  }
  delay(100);
}

